@@ -43,7 +43,7 @@
 #' @export
 
 
-SA2008=function(n,k,N,T0,rate,Tmin,Imax,p=50,q=1){
+SA2008=function(n,k,N,T0,rate,Tmin,Imax,p=15,q=1){
   #n and k are the rs and fa.
   #N: maximum number of iterations.
   #T0: initial temperature
@@ -114,8 +114,8 @@ SA2008=function(n,k,N,T0,rate,Tmin,Imax,p=50,q=1){
         #step 4 ends
 
 
-        a=phi_p(X=Xnew,p=p)       #step 5 begins here
-        b=phi_p(X=X,p=p)
+        a=phi_p(X=Xnew,p=p,q=q)       #step 5 begins here
+        b=phi_p(X=X,p=p,q=q)
         if (a<b){X=Xnew;Flag=1}
         if (a>=b){
           prob=exp((b-a)/TP)
@@ -123,7 +123,7 @@ SA2008=function(n,k,N,T0,rate,Tmin,Imax,p=50,q=1){
           if(draw==1){X=Xnew;Flag=1}
         }                         #step 5 ends here
 
-        c=phi_p(X=Xbest,p=p)
+        c=phi_p(X=Xbest,p=p,q=q)
         if (a<c){Xbest=Xnew;I=1}
         if (a>=c){I=I+1}
 
